#
# This is the SPEC file for creating binary and source RPMs for the Qubes DB.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

Name:		qubes-db
Version:	4.0.17
Release:	1%{?dist}
Summary:	QubesDB tools

Group:		Qubes
License:	GPL
URL:		http://www.qubes-os.org/

BuildRequires:	gcc
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	systemd-devel
BuildRequires:  python%{python3_pkgversion}-devel
Requires:	qubes-libvchan-xen
# XXX: VMM specific
Requires:   xen-libs >= 2001:4.6.1-20
Source0:    %{name}-%{version}.tar.gz

%description
QubesDB management tools and daemon.

%package libs
Summary:	QubesDB libs
Group:		Qubes

%description libs
QubesDB client library.

%package devel
Summary:	QubesDB client header files
Group:		Qubes
Requires:	qubes-db-libs

%description devel
Header files for QubesDB client library and daemon protocol.

%package -n python%{python3_pkgversion}-qubesdb
Summary:    Python%{python3_pkgversion} bindings for QubesDB
Requires:   qubes-db-libs
%{?python_provide:%python_provide python%{python3_pkgversion}-qubesdb}

%description -n python%{python3_pkgversion}-qubesdb
Python3 bindings for QubesDB

%prep
%setup -q 

%build
%{?set_build_flags}
make %{?_smp_mflags} PYTHON=%{__python3} BACKEND_VMM=xen all

%install
make install \
         PYTHON=%{__python3} \
         DESTDIR=%{buildroot} \
         LIBDIR=%{_libdir} \
         BINDIR=%{_bindir} \
         SBINDIR=%{_sbindir}

%files
%doc
%{_bindir}/qubesdb-cmd
%{_bindir}/qubesdb-read
%{_bindir}/qubesdb-read-bool
%{_bindir}/qubesdb-write
%{_bindir}/qubesdb-rm
%{_bindir}/qubesdb-multiread
%{_bindir}/qubesdb-list
%{_bindir}/qubesdb-watch
%{_sbindir}/qubesdb-daemon

%files libs
%{_libdir}/libqubesdb.so

%files -n python%{python3_pkgversion}-qubesdb
%{python3_sitearch}/QubesDB-*egg-info
%{python3_sitearch}/qubesdb.*.so

%files devel
/usr/include/qubesdb.h
/usr/include/qubesdb-client.h

%changelog
* Thu Jan 06 2022 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qubesdb.git

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eab4953
- version 4.0.17

* Wed Jan 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - abc3913
- Use $(file <) instead of $(shell cat)

* Wed Jan 05 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 318c4c3
- spec: fix systemctl path

* Wed Jan 05 2022 herypt <70331266+herypt@users.noreply.github.com> - 730340b
- Fix memory leak

* Wed Jan 05 2022 3hhh <tripleh@hackingthe.net> - a242a5d
- qubesdb-cmd watch: some doc clarifications for -n

* Wed Jan 05 2022 Shawn Anastasio <shawn@anastas.io> - e907331
- client: Treat getopt(3) return value as int instead of char

* Wed Jan 05 2022 Otto Sabart <seberm@seberm.com> - 7e55187
- archlinux: bump python dependency to v3.11

* Wed Jan 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a71826f
- version 4.0.16

* Wed Jan 06 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 907946b
- Add .gitlab-ci.yml

* Wed Jan 06 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 554243f
- debian: update control for python deps

* Wed Jan 06 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 98a050d
- debian: update compat

* Wed Jan 06 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cdbc60c
- debian: update control

* Tue Jan 05 2021 Olivier MEDOC <o_medoc@yahoo.fr> - 9c56b2c
- archlinux: pin PKGBUILD to python3.X major version as new python version will break the API

* Fri Oct 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9c1e5b5
- version 4.0.15

* Fri Oct 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b2de44b
- travis: update config

* Fri Oct 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fd2c5c2
- Drop python2 support

* Fri Oct 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 616073a
- version 4.0.14

* Wed May 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0ce152b
- version 4.0.13

* Thu Apr 30 2020 Ivan Kardykov <49684805+jevank@users.noreply.github.com> - c0e8c91
- Fix uppercase write bug

* Tue Feb 18 2020 Neowutran <me@neowutran.ovh> - 3984415
- fix QubesOS/qubes-issues#5658, keep python2 in qubesdb.c

* Sun Oct 20 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a2f5b36
- travis: switch to bionic

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 30320e4
- version 4.0.12

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 55d36a8
- Fix permissions of header files

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b0b9383
- daemon: make systemd linking optional

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bdb06e5
- rpm: fix build dependencies

* Mon Sep 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3e5dcd0
- version 4.0.11

* Fri Aug 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fc78f6d
- travis: update Fedora versions, switch to xenial

* Fri Aug 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 799a0f8
- python: fix gcc -Wsign-compare warnings

* Fri Aug 09 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 7c7a33f
- daemon: fix handling empty entries

* Fri Aug 09 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 598cc4e
- Daemon: fixed crash when trying to remove '/'

* Fri Aug 09 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9c22f8a
- spec.in: use %{python3_pkgversion}

* Mon Oct 08 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1483c29
- version 4.0.10

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 32db462
- travis: add fc29

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 87de0cb
- rpm: add BR: gcc

* Sat Sep 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adadcf4
- rpm: add missing BR: systemd-devel

* Fri Sep 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5b20e2b
- version 4.0.9

* Fri Aug 03 2018 unman <unman@thirdeyesecurity.org> - 3103035
- Remove wheezy and trusty builds. Consolidate Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 586bd96
- debian: unify Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f03ff8c
- travis: add fc28 and buster

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d7702c
- rpm: use build flags provided by the distribution

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6385bcc
- version 4.0.8

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0a41f05
- daemon: fix error message format string

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2d164cc
- version 4.0.7

* Tue Jul 10 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3cfab77
- windows: automatically determine newest SDK version

* Sat Jul 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c79b10d
- windows: update for vs2017

* Sat Jul 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b957321
- windows: fix few compile warnings

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4579b63
- version 4.0.6

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8a1f1c8
- travis: add centos7

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a5938f0
- rpm: fix packaging

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e21c9e3
- travis: update Fedora versions

